@@ -29,7 +29,7 @@ def load_ARG_mapping():
 
 def load_ARG_length():
     ARG_length = dict()
-    for lines in open(args.d.replace('.structure.txt','.db.fasta.length.txt'),'r'):
+    for lines in open(args.d.replace('.structure.txt','.db.fasta.length'),'r'):
         lines_set = lines.split('\n')[0].split('\t')
         ARG,ARG2,genelength = lines_set[0:3]
         ARG_length.setdefault(ARG,int(genelength)*3) # AA to DNA
